![Esbonio logo](https://github.com/swyddfa/esbonio/blob/release/resources/io.github.swyddfa.Esbonio.svg?raw=true)
# Esbonio [![PyPI](https://img.shields.io/pypi/v/esbonio?style=flat-square)](https://pypi.org/project/esbonio) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/esbonio?style=flat-square)](https://pypi.org/project/esbonio)

Esbonio - to explain.

**This package is in early development**

A [Language Server](https://microsoft.github.io/language-server-protocol/) that aims to make it easier to work with Sphinx documentation projects in editors that support it.
## Installation

The Language Server can be installed via pip.

```
$ pip install esbonio
```
